'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.BasePicker = undefined;

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _utils = require('../utils.js');

var _components = require('../components');

var _ = require('.');

var _moment = require('moment');

var _moment2 = _interopRequireDefault(_moment);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

/** Base class for DatePicker, DateTimePicker, DatesRangePicker.
 * Expects that inheritors have state with some of the following properties:
 * 
 *    activeDate:   {moment} This object is lifted up, it represents a Picker's selected value
 *    dateToShow:   {moment} This object determines what years are currently visible in YearPicker or
 *                           what month is currently viewed on calendar. In other words it determines
 *                           what is showed.
 *    year:         {string} Selected year. For example '2012'.
 *    month:        {string} Selected month. For example 'Jan'.
 *    activeHour:   {string} Selected hour. For example '05'.
 *    activeMinute: {string} Selected minute. For example '15'.
 *    datesRange:   {object} Selected dates range. For example {start: moment(2012-01-01), end: moment(2012-01-15)}.
 */
var BasePicker = function (_React$Component) {
  _inherits(BasePicker, _React$Component);

  function BasePicker() {
    var _ref;

    var _temp, _this, _ret;

    _classCallCheck(this, BasePicker);

    for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    return _ret = (_temp = (_this = _possibleConstructorReturn(this, (_ref = BasePicker.__proto__ || Object.getPrototypeOf(BasePicker)).call.apply(_ref, [this].concat(args))), _this), _this.getTime = function (_ref2) {
      var _ref2$hour = _ref2.hour,
          hour = _ref2$hour === undefined ? '' : _ref2$hour,
          _ref2$minute = _ref2.minute,
          minute = _ref2$minute === undefined ? '' : _ref2$minute;

      return hour + ':' + minute;
    }, _this.showNextYear = function () {
      _this.setState(function (_ref3) {
        var dateToShow = _ref3.dateToShow;

        var nextYear = dateToShow.clone();
        nextYear.add(1, 'Y');
        return { dateToShow: nextYear };
      });
    }, _this.showPrevYear = function () {
      _this.setState(function (_ref4) {
        var dateToShow = _ref4.dateToShow;

        var prevYear = dateToShow.clone();
        prevYear.add(-1, 'Y');
        return { dateToShow: prevYear };
      });
    }, _this.showNextMonth = function () {
      _this.setState(function (_ref5) {
        var dateToShow = _ref5.dateToShow;

        var nextMonth = dateToShow.clone();
        nextMonth.add(1, 'M');
        return { dateToShow: nextMonth };
      });
    }, _this.showPrevMonth = function () {
      _this.setState(function (_ref6) {
        var dateToShow = _ref6.dateToShow;

        var prevMonth = dateToShow.clone();
        prevMonth.add(-1, 'M');
        return { dateToShow: prevMonth };
      });
    }, _this.showNextDay = function () {
      _this.setState(function (_ref7) {
        var activeDate = _ref7.activeDate;

        var nextDay = activeDate.clone();
        nextDay.add(1, 'd');
        _this.props.onDateChange(null, { value: nextDay });
        return { activeDate: nextDay };
      });
    }, _this.showPrevDay = function () {
      _this.setState(function (_ref8) {
        var activeDate = _ref8.activeDate;

        var prevDay = activeDate.clone();
        prevDay.add(-1, 'd');
        _this.props.onDateChange(null, { value: prevDay });
        return { activeDate: prevDay };
      });
    }, _this.onDateClick = function (event, data) {
      var onDateChange = _this.props.onDateChange;


      _this.setState({
        activeDate: data.value
      });
      onDateChange(event, data);
    }, _this.onHourClick = function (event, data) {
      _this.setState(function (prevState) {
        var newData = (0, _utils.cloneReplaceValue)(data, _this.getTime({
          hour: data.value,
          minute: ''
        }));
        _this.props.onTimeChange(event, newData);
        return {
          activeHour: data.value
        };
      });
    }, _this.onMinuteClick = function (event, data) {
      _this.setState(function (prevState) {
        var newData = (0, _utils.cloneReplaceValue)(data, _this.getTime({
          hour: prevState.activeHour,
          minute: data.value
        }));
        _this.props.onTimeChange(event, newData);
        return {
          activeMinute: data.value
        };
      });
    }, _this.onYearChange = function (event, data) {
      var date = {
        year: data.value
      };
      _this.setState({
        dateToShow: (0, _moment2.default)(date),
        year: data.value
      });
    }, _this.onMonthChange = function (event, data) {
      var date = {
        year: _this.state.year,
        month: (0, _utils.monthIndex)(data.value)
      };
      _this.setState({
        dateToShow: (0, _moment2.default)(date),
        month: data.value
      });
    }, _this.yearModeContent = function () {
      return _react2.default.createElement(_.YearPicker, {
        standalone: false,
        onYearChange: _this.onYearChange });
    }, _this.monthModeContent = function () {
      return _react2.default.createElement(
        _react2.default.Fragment,
        null,
        _react2.default.createElement(_components.PickerHeader, {
          onNextBtnClick: _this.showNextYear,
          onPrevBtnClick: _this.showPrevYear,
          activeYear: _this.state.dateToShow.format('YYYY'),
          width: '3' }),
        _react2.default.createElement(_components.MonthPickerComponent, {
          activeMonth: _this.state.dateToShow.format('MMM'),
          onMonthClick: _this.onMonthChange })
      );
    }, _this.dayModeContent = function () {
      return _react2.default.createElement(
        _react2.default.Fragment,
        null,
        _react2.default.createElement(_components.PickerHeader, {
          onNextBtnClick: _this.showNextMonth,
          onPrevBtnClick: _this.showPrevMonth,
          activeDate: _this.state.dateToShow,
          showWeeks: true,
          width: '7' }),
        _react2.default.createElement(_components.DatePickerComponent, {
          onDateClick: _this.onDateClick,
          activeDate: _this.state.activeDate,
          showedMonth: _this.state.dateToShow })
      );
    }, _this.getDatePickerContent = function () {
      var startMode = _this.props.startMode;
      var _this$state = _this.state,
          year = _this$state.year,
          month = _this$state.month;

      if (startMode === 'year' && !year) return _this.yearModeContent();
      if (startMode === 'year' && !month) return _this.monthModeContent();
      if (startMode === 'month' && !month) return _this.monthModeContent();
      return _this.dayModeContent();
    }, _this.getDateTimePickerContent = function () {
      var _this$state2 = _this.state,
          activeDate = _this$state2.activeDate,
          activeHour = _this$state2.activeHour,
          activeMinute = _this$state2.activeMinute;

      var headerWidth = activeHour ? '3' : activeDate ? '4' : '7';
      if (!activeDate) {
        return _this.getDatePickerContent();
      }
      return _react2.default.createElement(
        _react2.default.Fragment,
        null,
        _react2.default.createElement(_components.PickerHeader, {
          onNextBtnClick: _this.showNextDay,
          onPrevBtnClick: _this.showPrevDay,
          activeDate: activeDate,
          includeDay: true,
          width: headerWidth }),
        _react2.default.createElement(_components.TimePickerComponent, {
          activeHour: activeHour,
          activeMinute: activeMinute,
          onHourClick: _this.onHourClick,
          onMinuteClick: _this.onMinuteClick })
      );
    }, _temp), _possibleConstructorReturn(_this, _ret);
  }

  return BasePicker;
}(_react2.default.Component);

exports.default = BasePicker;
exports.BasePicker = BasePicker;